@@ -199,7 +199,7 @@ def check_ERC_standard(function_signatures, standard='ERC20'):
     input: list, string
     output: bool
 
-    standard:
+    standard
     - ERC20: Check if the contract follows ERC20.
     - ERC721: Check if the contract follows ERC721.
     - ERC777: Check if the contract follows ERC777.
@@ -221,3 +221,46 @@ def check_ERC_standard(function_signatures, standard='ERC20'):
         raise ValueError(
             'Parameter standard can only be in [\'ERC20\', \'ERC721\', \'ERC777\'].')
 
+
+def split_bytecode(bytecode):
+    '''
+    Split contract creation code.
+
+    input: string
+    output: tuple 
+
+    structure of contract creation code
+    +-----------------------+
+    | Deployment Bytecode   |
+    +-----------------------+
+    | Runtime Bytecode      |
+    +-----------------------+
+    | BZZR: Swarm Source    |
+    +-----------------------+
+    | Constructor Arguments |
+    +-----------------------+
+    '''
+
+    runtime_start = 0
+    bzzr_start = 0
+    args_start = 0
+
+    bzzr = ''
+    arguments = []
+
+    bytecode = bytecode.lower()
+
+    runtime_start = bytecode.find('f300') + 4
+    deployment_bytecode = bytecode[:runtime_start]
+
+    bzzr_start = bytecode.find('a165627a7a72305820') + 18
+    runtime_bytecode = bytecode[runtime_start:bzzr_start]
+    bzzr = 'bzzr: '+bytecode[bzzr_start:bzzr_start+64]
+
+    args_start = bzzr_start+64+4
+    for i in range(args_start, len(bytecode), 64):
+        aug = str('Arg [{}]: '.format(
+            str((i-args_start) // 64))+bytecode[i:i+64])
+        arguments.append(aug)
+
+    return deployment_bytecode, runtime_bytecode, bzzr, arguments
